@@ -6,7 +6,7 @@
 
 package stun
 
-import "github.com/pion/stun/internal/hmac"
+import "github.com/pion/stun/v3/internal/hmac"
 
 // CheckSize returns *AttrLengthError if got is not equal to expected.
 func CheckSize(a AttrType, got, expected int) error {
