@@ -11,7 +11,7 @@ import (
 	"log"
 	"os"
 
-	"github.com/pion/stun"
+	"github.com/pion/stun/v3"
 )
 
 func main() {
