@@ -10,7 +10,7 @@ import ( //nolint:gci
 	"fmt"
 	"strings"
 
-	"github.com/pion/stun/internal/hmac"
+	"github.com/pion/stun/v3/internal/hmac"
 )
 
 // separator for credentials.
